@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 # Copyright (c) 2016 b<>com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
-
 from django.core import urlresolvers
 from django import http
 from mox3.mox import IsA  # noqa
@@ -23,8 +20,6 @@ from mox3.mox import IsA  # noqa
 from watcher_dashboard import api
 from watcher_dashboard.test import helpers as test
 
-LOG = logging.getLogger(__name__)
-
 INDEX_URL = urlresolvers.reverse(
     'horizon:admin:audit_templates:index')
 CREATE_URL = urlresolvers.reverse(
